# Copyright 2006 Javier Fernandez-Sanguino <jfs@debian.org>
# This file contains all of the Debian-unique subroutines
# $Id: $

####################################################################
#
#  This module makes up the Debian specific API routines.
#  
####################################################################
#
#  Subroutine Listing:
#
#     &B_statoverride($):     Takes a file name and runs the
#                             adds it current permissions to the
#                             dpkg-statoverride list
#
#####################################################################


###################################################################
#  &B_statoverride($file);
#    This subroutine is called after a file is modified.  It will
#    add the current permissions and owner to the dpkg-statoverride
#    lists so that the changes are preserved on package upgrades.
#
#  Returns: 0 if statoverride was succesfully called (or was not called)
#           1 if the called of dpkg-statoverride returned an error
#
##################################################################
sub B_statoverride($){
    my $file = $_[0];
    if(&GetDistro =~ "^DB" && -e "/usr/sbin/dpkg-statoverride") {
	    my $uid= (stat($file))[4];
	    my $gid= (stat($file))[5];
	    my $perm = sprintf("%04o", $new_perm);
	    my @override = ("/usr/sbin/dpkg-statoverride", "--force", "--add", "#$uid", "#$gid", "$perm", "$file");
	    &B_log("ACTION","Setting permissions with dpkg-statoverride:".
			    join(" ", @override)."\n");
	    if ( system (@override) != 0 ) {
		    &B_log("ERROR","Couldn't set a dpkg-statoverride for $file: $?\n");
		    &B_log("ERROR","Couldn't set a dpkg-statoverride for $file: $?\n");
		    return 1;
	    }
    }
   return 0;
}


1;
